"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
const bundle_analyzer_1 = __importDefault(require("@next/bundle-analyzer"));
const next_optimized_images_1 = __importDefault(require("next-optimized-images"));
const next_transpile_modules_1 = __importDefault(require("next-transpile-modules"));
const with_css_1 = __importDefault(require("./plugins/with-css"));
const with_graphql_basic_1 = __importDefault(require("./plugins/with-graphql-basic"));
// Export a plugin function that just goes through and calls our chain
// TODO: use NextConfig from next once we upgrade to v10 (https://app.asana.com/0/1100423001970639/1199650430485547)
function withHashicorp(options = {}) {
    if (!options.css)
        options.css = {};
    if (!options.dato)
        options.dato = {};
    if (!options.transpileModules)
        options.transpileModules = [];
    // TODO: use NextConfig from next once we upgrade to v10 (https://app.asana.com/0/1100423001970639/1199650430485547)
    return function withHashicorpInternal(nextConfig = {}) {
        var _a, _b;
        const chain = [
            next_optimized_images_1.default,
            bundle_analyzer_1.default({ enabled: process.env.ANALYZE === 'true' }),
            with_css_1.default(options.css),
            with_graphql_basic_1.default(),
        ];
        // If there are explicitly defined modules to be transpiled, add them to the array
        // Also, don't transpile modules from this lib
        if (options.transpileModules) {
            chain.unshift(next_transpile_modules_1.default([
                ...options.transpileModules,
                '@hashicorp/nextjs-scripts',
                '@hashicorp/react-.*',
            ]));
        }
        // Set dato token if a custom token is provided
        if ((_a = options.dato) === null || _a === void 0 ? void 0 : _a.token) {
            if (!nextConfig.env)
                nextConfig.env = {};
            process.env.HASHI_DATO_TOKEN = options.dato.token;
            nextConfig.env.HASHI_DATO_TOKEN = options.dato.token;
        }
        // Set dato environment if custom environment is provided
        if ((_b = options.dato) === null || _b === void 0 ? void 0 : _b.environment) {
            if (!nextConfig.env)
                nextConfig.env = {};
            process.env.HASHI_DATO_ENVIRONMENT = options.dato.environment;
            nextConfig.env.HASHI_DATO_ENVIRONMENT = options.dato.environment;
        }
        // the difference between defaults and permanents are that defaults will
        // be overridden by user land configuration, whereas permanents are always
        // tacked on to the end and therefore can't be overidden
        // header overriding docs: https://nextjs.org/docs/api-reference/next.config.js/headers#header-overriding-behavior
        // TODO: use NextConfig from next once we upgrade to v10 (https://app.asana.com/0/1100423001970639/1199650430485547)
        const defaultHeaders = [];
        const permanentHeaders = [
            {
                source: '/:path*{/}?',
                headers: [
                    {
                        key: 'X-Frame-Options',
                        value: 'SAMEORIGIN',
                    },
                ],
            },
        ];
        // support tipBranch config, which activates noindex HTTP headers
        // MKTG-030 - https://docs.google.com/document/d/1AlBW3DPT7D54vDQa0P6QBMjTKqssJFPDz1CuthkI5oM/edit#
        if (nextConfig.tipBranch &&
            process.env.VERCEL_GIT_COMMIT_REF == nextConfig.tipBranch) {
            defaultHeaders.push({
                source: '/:path*{/}?',
                headers: [{ key: 'X-Robots-Tag', value: 'noindex' }],
            });
        }
        // if there are user land headers, combine them with defaults & permanents
        if (nextConfig.headers) {
            // TODO: use NextConfig from next once we upgrade to v10 (https://app.asana.com/0/1100423001970639/1199650430485547)
            nextConfig.headers = nextConfig.headers().then((res) => {
                return [...defaultHeaders, ...res, ...permanentHeaders];
            });
        }
        else {
            // else, just add defaults and permanent headers and resolve the promise
            nextConfig.headers = Promise.resolve([
                ...defaultHeaders,
                ...permanentHeaders,
            ]);
        }
        return chain.reduce((acc, next) => next(acc), nextConfig);
    };
}
module.exports = withHashicorp;
